# sb2sep
Separate Stellar Component Spectra and Calculate Radial Velocities in SB2 Binary Systems

Please see the [documentation](https://jsinkbaek.github.io/sb2sep/) for a description and guides on how to use the software.

The package can be installed using pip:

``pip install sb2sep``


Requirements:

python 3.6 or higher
numpy version >= 1.19.5
matplotlib version >= 3.3.4
lmfit version >= 1.0.2
joblib version >= 0.17.0
scipy version >= 4.1
For test script also:

barycorrpy version >= 0.4.1
astropy version >= 4.1
